@@ -1,13 +1,13 @@
-# Copyrights 2006-2007 by Mark Overmeer.
+# Copyrights 2006-2008 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.02.
+# Pod stripped from pm file by OODoc 1.03.
 use warnings;
 use strict;
 
 package XML::Compile::Util;
 use vars '$VERSION';
-$VERSION = '0.59';
+$VERSION = '0.60';
 use base 'Exporter';
 
 my @constants  = qw/XMLNS SCHEMA1999 SCHEMA2000 SCHEMA2001 SCHEMA2001i/;
@@ -27,7 +27,9 @@ use Log::Report 'xml-compile';
 
 
 sub pack_type($;$)
-{   @_==1 || !defined $_[0] || !length $_[0] ? $_[0] : "{$_[0]}$_[1]"
+{      @_==1 ? $_[0]
+    : !defined $_[0] || !length $_[0] ? $_[1]
+    : "{$_[0]}$_[1]"
 }
 
 
